# -*- coding: UTF-8 -*-
import re
import json


def get_tags():
    return ['2', '2.3']


def run_task(runcontext):
    ansible_params = runcontext.get_mod_params_instance()
    runcontext.set_mod_params_instance(ansible_params, "chdir", None)
    runcontext.set_mod_params_instance(ansible_params, "executable", None)

    module = runcontext.get_module_file("shell.py")
    rc, out = run_audit(runcontext, ansible_params, module)
    return rc, out


def run_audit(runcontext, ansible_params, module):
    curtemplate = runcontext.get_template()
    ret_code = -1
    tmp_vars = {}
    tmp_vars["policyresult"] = "failed"

    tmp_vars["checkresult1"] = "failed"
    tmp_vars["scancommand1"] = '''systemctl is-enabled sshd'''
    tmp_vars["systemvalue1"] = ""

    tmp_vars["checkresult2"] = "failed"
    tmp_vars["scancommand2"] = r'''path=$(grep "^\s*Banner\s*" /etc/ssh/sshd_config 2>/dev/null | awk '{print $2}');if [ -n "$path" ]; then cat $path 2>/dev/null | grep -v '^[[:space:]]*#'; fi '''
    tmp_vars["systemvalue2"] = ""

    runcontext.set_mod_params_instance(ansible_params, "command", tmp_vars["scancommand1"])
    arc1, astdout1, astderr1 = runcontext.invoke_module(module, ansible_params)
    runcontext.log_debug_invoke_result(arc1, astdout1, astderr1)
    runcontext.sleep()

    runcontext.set_mod_params_instance(ansible_params, "command", tmp_vars["scancommand2"])
    arc2, astdout2, astderr2 = runcontext.invoke_module(module, ansible_params)
    runcontext.log_debug_invoke_result(arc2, astdout2, astderr2)
    runcontext.sleep()

    if arc1 != 0:
        return (-2, "Failed to invoke module: %s." % astdout1)
    resultjson1 = json.loads(astdout1)
    astdout1 = resultjson1["stdout"]
    astderr1 = resultjson1["stderr"]
    match1 = re.match(r"enabled", astdout1)
    tmp_vars["systemvalue1"] = astdout1
    if not match1:
        tmp_vars["checkresult1"] = "pass"

    if arc2 != 0:
        return (-2, "Failed to invoke module: %s." % astdout2)
    resultjson2 = json.loads(astdout2)
    astdout2 = resultjson2["stdout"]
    astderr2 = resultjson2["stderr"]
    match2 = re.findall(r"(.*(\\v|\\r|\\m|\\s).*)|^\s*$", astdout2, re.I)
    tmp_vars["systemvalue2"] = astdout2
    if match2 == []:
        tmp_vars["checkresult2"] = "pass"

    if tmp_vars["checkresult1"] == "pass" or tmp_vars["checkresult2"] == "pass":
        ret_code = 0
        tmp_vars["policyresult"] = "pass"

    rc, out = curtemplate.render(runcontext.get_template_file('t_2_3.j2'), **tmp_vars)

    if rc == False:
        return (-2, "Failed to render template.%s" % out)

    return ret_code, out
